const chai = require('chai');
const chaiAsPromised = require('chai-as-promised');
const { getZonePrototypesBlackList } = require('../../utils');
const { USER_ROLES_VALUES } = require('enums').COMMON;

chai.use(chaiAsPromised);
const { expect } = chai;

const boundary_list = ['boundary_out', 'boundary_in'];

describe('customZonePrototype functions', () => {
    describe('getZonePrototypesBlackList', () => {
        it('it should return empty array for company admin role', () => {
            const black_list = getZonePrototypesBlackList(USER_ROLES_VALUES.COMPANY_ADMIN);
            
            expect(black_list).to.be.a('array');
            expect(black_list.length).to.equal(0);
        });
        
        it('it should return array with boundary zones for project user role', () => {
            const black_list = getZonePrototypesBlackList(USER_ROLES_VALUES.PROJECT_USER);
            
            expect(black_list).to.be.a('array');
            expect(black_list.length).to.equal(2);
            expect(black_list).to.deep.equal(boundary_list);
        });
        
        it('it should return array with boundary zones for project system admin role', () => {
            const black_list = getZonePrototypesBlackList(USER_ROLES_VALUES.PROJECT_SYSTEM_ADMIN);
            
            expect(black_list).to.be.a('array');
            expect(black_list.length).to.equal(2);
            expect(black_list).to.deep.equal(boundary_list);
        });
        
        it('it should return array with boundary zones for project operational admin role', () => {
            const black_list = getZonePrototypesBlackList(USER_ROLES_VALUES.PROJECT_OPERATIONS_ADMIN);
            
            expect(black_list).to.be.a('array');
            expect(black_list.length).to.equal(2);
            expect(black_list).to.deep.equal(boundary_list);
        });
        
        it('it should return empty array for unknown user role', () => {
            const black_list = getZonePrototypesBlackList(undefined);
            
            expect(black_list).to.be.a('array');
            expect(black_list.length).to.equal(0);
        });
    });
});
