const { BOUNDARY_ZONES } = require('../../constants');
const { USER_ROLES_VALUES } = require('enums').COMMON;
const UID = require('./../../../../routes/arrayfunctions').getUUID;


function User(user) {
    this.uid = user.uid;
    this.role = user.role;
}

function UserFactory() {
    this.createCompanyAdmin = () => new User({ uid: UID(), role: USER_ROLES_VALUES.COMPANY_ADMIN });
    this.createProjectUser = () => new User({ uid: UID(), role: USER_ROLES_VALUES.PROJECT_USER });
    this.createProjectSystemAdmin = () => new User({ uid: UID(), role: USER_ROLES_VALUES.PROJECT_SYSTEM_ADMIN });
    this.createProjectOperationsAdmin = () => new User({ uid: UID(), role: USER_ROLES_VALUES.PROJECT_OPERATIONS_ADMIN });
    this.createUnknownRoleUser = () => new User({ uid: UID(), role: 'unknown role' });
}

function Zone(zone) {
    this.zone_id = zone.zone_id || 0;
    this.uid = zone.uid;
    this.zone_type_name = zone.zone_type_name;
    this.user_params = zone.user_params || {};
    this.getProperties = () => ({ ...this });
}

Zone.prototype.setCoupleId = function (coupled) {
    this.user_params = { coupled };
};

function ZoneFactory() {
    this.createKeepInZone = coupled => new Zone({ uid: UID(), zone_type_name: 'keep_in', user_params: { coupled: 0 || coupled } });
    this.createKeepOutZone = coupled => new Zone({ uid: UID(), zone_type_name: 'keep_out', user_params: { coupled: 0 || coupled } });
    this.createInfoZone = coupled => new Zone({ uid: UID(), zone_type_name: 'information', user_params: { coupled: 0 || coupled } });
    this.createOneWay = coupled => new Zone({ uid: UID(), zone_type_name: 'one_way', user_params: { coupled: 0 || coupled } });
    this.createBoundaryInZone = coupled => new Zone({ uid: UID(), zone_type_name: BOUNDARY_ZONES.BOUNDARY_IN, user_params: { coupled: 0 || coupled } });
    this.createBoundaryOutZone = coupled => new Zone({ uid: UID(), zone_type_name: BOUNDARY_ZONES.BOUNDARY_OUT, user_params: { coupled: 0 || coupled } });
}

function ZoneListFactory(number) {
    const zoneFactory = new ZoneFactory();
    this.number = 2 || number;
    this.createZonesListByLength = () => {
        const zonesList = [];
        for (let i = 0; i < this.number; i += 1) {
            zonesList.push(zoneFactory.createBoundaryInZone());
            zonesList.push(zoneFactory.createBoundaryOutZone());
            zonesList.push(zoneFactory.createInfoZone());
            zonesList.push(zoneFactory.createKeepInZone());
            zonesList.push(zoneFactory.createKeepOutZone());
            zonesList.push(zoneFactory.createOneWay());
        }
        return zonesList;
    };
    
    this.createNoBoundaryZonesList = () => {
        const zonesList = [];
        for (let i = 0; i < this.number; i += 1) {
            zonesList.push(zoneFactory.createInfoZone());
            zonesList.push(zoneFactory.createKeepInZone());
            zonesList.push(zoneFactory.createKeepOutZone());
            zonesList.push(zoneFactory.createOneWay());
        }
        return zonesList;
    };
}

module.exports = {
    UserFactory,
    ZoneFactory,
    ZoneListFactory,
};
