const logger = require('../../../utils/logger/index');
const Service = require('./service');


async function getZoneHandler(req, res, next) {
    try {
        const zones = await Service.getZones(req);
        res.json({ zones });
    } catch (e) {
        next(e);
    }
}

async function createZoneHandler(req, res, next) {
    try {
        const zone = await Service.createZone(req, next);
        res.json(zone);
    } catch (err) {
        logger.error('[addon createZone] error: ', err);
        next(err);
    }
}

async function updateZoneHandler(req, res, next) {
    try {
        const updatedZone = await Service.updateZone(req, next);
        res.json(updatedZone);
    } catch (err) {
        logger.error('[addon updateZone] error: ', err);
        next(err);
    }
}

async function deleteZoneHandler(req, res, next) {
    try {
        await Service.deleteZone(req, next);
        res.status(204).end();
    } catch (err) {
        logger.error('[addon deleteZone] error: ', err);
        next(err);
    }
}


module.exports = {
    deleteZoneHandler,
    createZoneHandler,
    updateZoneHandler,
    getZoneHandler,
};
