const { parseSafe } = require('utils');
const { ZoneRepo } = require('../repository/zones');


async function getZoneById(zone_id, project_uid) {
    if (!zone_id || typeof zone_id !== 'number' || typeof project_uid !== 'string') {
        return null;
    }
    return ZoneRepo.getZoneBySequenceAndProject(zone_id, project_uid);
}

async function updateCoupledZone(zoneUid, coupledId) {
    if (!zoneUid || typeof zoneUid !== 'string' || typeof coupledId !== 'number' || Number.isNaN(coupledId)) {
        return null;
    }
    return ZoneRepo.updateCoupledZone(coupledId, zoneUid);
}

async function coupleZone(zoneUid, coupledId) {
    return updateCoupledZone(zoneUid, coupledId);
}

async function decoupleZone(zoneUid) {
    return updateCoupledZone(zoneUid, 0);
}

async function getZoneByUid(zoneUid) {
    if (!zoneUid || typeof zoneUid !== 'string') {
        return null;
    }
    const zone = await ZoneRepo.getZoneByUid(zoneUid);
    if (zone) {
        zone.user_params = parseSafe(zone.user_params);
    }
    return zone;
}


module.exports = {
    getZoneByUid,
    getZoneById,
    coupleZone,
    decoupleZone,
    updateCoupledZone,
};
